#ifndef _GLOBAL_H
#define _GLOBAL_H

#define KILOBYTE       1024
#define MEGABYTE    1048576
#define GIGABYTE 1073741824

#define MINUTE    60
#define HOUR    3600
#define DAY    86400

#define TIMER_OFF -1

#endif
